@@ -6,13 +6,13 @@
 
 '''
 from trytond.pool import Pool
-from webshop import WebShop, BannerCategory, Banner, Article, Website
+from webshop import WebShop, BannerCategory, Banner, Article, \
+    Website, ArticleCategory, MenuItem
 from product import Product
 from invoice import Invoice
-from sale import Sale
+from sale import Sale, SaleLine
 from party import Address
 from shipment import ShipmentOut
-from cart import Cart
 
 
 def register():
@@ -26,7 +26,9 @@ def register():
         Address,
         ShipmentOut,
         Sale,
+        SaleLine,
         Website,
-        Cart,
+        ArticleCategory,
+        MenuItem,
         module='nereid_webshop', type_='model'
     )
