@@ -16,10 +16,9 @@ from nereid import jsonify, flash, request, url_for, route, redirect, \
     render_template, abort
 from nereid.contrib.locale import make_lazy_gettext
 
-_ = make_lazy_gettext('gift_card')
-
 from forms import GiftCardForm
 
+_ = make_lazy_gettext('gift_card')
 
 __all__ = ['Product']
 
@@ -30,18 +29,26 @@ class Product:
     "Product extension for Nereid"
     __name__ = "product.product"
 
+    def serialize(self, purpose=None):
+        """
+        Downstream implementation which adds a key called inventory_status
+        to the dictionary if purpose is 'variant_selection'.
+
+        :param purpose: String which decides structure of dictionary
+        """
+        res = super(Product, self).serialize(purpose=purpose)
+
+        if purpose == 'variant_selection':
+            res.update({
+                'inventory_status': self.inventory_status(),
+            })
+
+        return res
+
     def get_default_image(self, name):
         "Returns default product image"
         ModelData = Pool().get('ir.model.data')
 
-        # Get default image from default_image_set of product template
-        # or product variant.
-        if self.use_template_images:
-            if self.template.default_image_set:
-                return self.template.default_image_set.image.id
-        elif self.default_image_set:
-            return self.default_image_set.image.id
-
         # Fallback condition if there is no default_image_set defined
         images = self.get_images()
         if images:
@@ -190,3 +197,18 @@ class Product:
                 'product.product.render_gift_card', uri=self.uri, **kwargs
             )
         return super(Product, self).get_absolute_url(**kwargs)
+
+    def get_menu_item(self, max_depth):
+        """
+        Return dictionary with serialized node for menu item
+        {
+            title: <display name>,
+            link: <url>,
+            record: <instance of record> # if type_ is record
+        }
+        """
+        return {
+            'record': self,
+            'title': self.name,
+            'link': self.get_absolute_url(),
+        }
