@@ -2,9 +2,10 @@
 
     Test Base Case
 
-    :copyright: (c) 2014 by Openlabs Technologies & Consulting (P) LTD
+    :copyright: (c) 2014-2015 by Openlabs Technologies & Consulting (P) LTD
     :license: GPLv3, see LICENSE for more details
 '''
+import random
 import datetime
 from decimal import Decimal
 from dateutil.relativedelta import relativedelta
@@ -14,6 +15,9 @@ import trytond.tests.test_tryton
 from trytond.tests.test_tryton import POOL, USER, CONTEXT
 from nereid.testing import NereidTestCase
 from trytond.transaction import Transaction
+from trytond.config import config
+
+config.set('database', 'path', '/tmp')
 
 
 class BaseTestCase(NereidTestCase):
@@ -22,9 +26,6 @@ class BaseTestCase(NereidTestCase):
     """
     def setUp(self):
         trytond.tests.test_tryton.install_module('nereid_webshop')
-        trytond.tests.test_tryton.install_module(
-            'payment_gateway_authorize_net'
-        )
 
         self.FiscalYear = POOL.get('account.fiscalyear')
         self.Account = POOL.get('account.account')
@@ -38,7 +39,7 @@ class BaseTestCase(NereidTestCase):
         self.ProductTemplate = POOL.get('product.template')
         self.Language = POOL.get('ir.lang')
         self.NereidWebsite = POOL.get('nereid.website')
-        self.SaleShop = POOL.get('sale.shop')
+        self.SaleChannel = POOL.get('sale.channel')
         self.Uom = POOL.get('product.uom')
         self.Country = POOL.get('country.country')
         self.Subdivision = POOL.get('country.subdivision')
@@ -54,9 +55,13 @@ class BaseTestCase(NereidTestCase):
         self.ArticleCategory = POOL.get('nereid.cms.article.category')
         self.Article = POOL.get('nereid.cms.article')
         self.Category = POOL.get('product.category')
+        self.StaticFolder = POOL.get('nereid.static.folder')
+        self.StaticFile = POOL.get('nereid.static.file')
+        self.SaleConfig = POOL.get('sale.configuration')
         self.ProductNodeRelationship = POOL.get(
             'product.product-product.tree_node'
         )
+        self.MenuItem = POOL.get('nereid.cms.menuitem')
         self.templates = {
             'shopping-cart.jinja':
                 'Cart:{{ cart.id }},{{get_cart_size()|round|int}},'
@@ -112,6 +117,13 @@ class BaseTestCase(NereidTestCase):
         :param displayed_on_eshop: Boolean field to display product
                                    on shop or not
         """
+        _code_list = []
+        code = random.choice('ABCDEFGHIJK')
+        while code in _code_list:
+            code = random.choice('ABCDEFGHIJK')
+        else:
+            _code_list.append(code)
+
         for values in vlist:
             values['name'] = name
             values['default_uom'], = self.Uom.search(
@@ -124,9 +136,10 @@ class BaseTestCase(NereidTestCase):
                 ('create', [{
                     'uri': uri,
                     'displayed_on_eshop': displayed_on_eshop,
+                    'code': code,
                 }])
             ]
-        return self.ProductTemplate.create(vlist)
+        return self.ProductTemplate.create(vlist)[0]
 
     def create_test_products(self):
         # Create product templates with products
@@ -182,7 +195,7 @@ class BaseTestCase(NereidTestCase):
             displayed_on_eshop=False
         )
 
-    def _create_auth_net_gateway_for_site(self):
+    def _create_auth_net_gateway_for_site(self, method='credit_card'):
         """
         A helper function that creates the authorize.net gateway and assigns
         it to the websites.
@@ -194,16 +207,25 @@ class BaseTestCase(NereidTestCase):
         cash_journal, = Journal.search([
             ('name', '=', 'Cash')
         ])
+        self.account_cash, = self.Account.search([
+            ('kind', '=', 'other'),
+            ('name', '=', 'Main Cash'),
+            ('company', '=', self.company.id)
+        ])
+        cash_journal.debit_account = self.account_cash
+        cash_journal.credit_account = self.account_cash
+        cash_journal.save()
 
-        gatway = PaymentGateway(
-            name='Authorize.net',
-            journal=cash_journal,
-            provider='authorize_net',
-            method='credit_card',
-            authorize_net_login='327deWY74422',
-            authorize_net_transaction_key='32jF65cTxja88ZA2',
-        )
-        gatway.save()
+        with Transaction().set_context({'use_dummy': True}):
+            gatway = PaymentGateway(
+                name='Authorize.net',
+                journal=cash_journal,
+                provider='dummy',
+                method=method,
+                authorize_net_login='327deWY74422',
+                authorize_net_transaction_key='32jF65cTxja88ZA2',
+            )
+            gatway.save()
 
         websites = NereidWebsite.search([])
         NereidWebsite.write(websites, {
@@ -371,7 +393,7 @@ class BaseTestCase(NereidTestCase):
         # Create a payment term
         payment_term, = self._create_payment_term()
 
-        shop_price_list, user_price_list = self._create_pricelists()
+        channel_price_list, user_price_list = self._create_pricelists()
         party1, = self.Party.create([{
             'name': 'Guest User',
         }])
@@ -387,6 +409,12 @@ class BaseTestCase(NereidTestCase):
             'name': 'Registered User 2',
         }])
 
+        sale_config = self.SaleConfig(1)
+        sale_config.payment_authorize_on = 'manual'
+        sale_config.payment_capture_on = 'sale_process'
+        sale_config.gift_card_method = 'order'
+        sale_config.save()
+
         # Create users and assign the pricelists to them
         self.guest_user, = self.NereidUser.create([{
             'party': party1.id,
@@ -437,29 +465,47 @@ class BaseTestCase(NereidTestCase):
             'credit_note_account': self._get_account_by_kind('other').id,
         }])
 
-        self.shop, = self.SaleShop.create([{
-            'name': 'Default Shop',
-            'price_list': shop_price_list,
+        self.channel, = self.SaleChannel.create([{
+            'name': 'Default Channel',
+            'price_list': channel_price_list,
             'warehouse': warehouse,
             'payment_term': payment_term,
             'company': self.company.id,
-            'users': [('add', [USER])]
+            'currency': self.company.currency.id,
+            'invoice_method': 'order',
+            'shipment_method': 'order',
+            'source': 'webshop',
+            'create_users': [('add', [USER])],
         }])
-        self.User.set_preferences({'shop': self.shop})
+
+        self.User.set_preferences({'current_channel': self.channel})
+
+        self.User.write(
+            [self.User(USER)], {
+                'main_company': self.company.id,
+                'company': self.company.id,
+                'current_channel': self.channel,
+            }
+        )
 
         self.default_node, = self.Node.create([{
             'name': 'root',
             'slug': 'root',
         }])
+        self.default_menuitem, = self.MenuItem.create([{
+            'type_': 'view',
+            'title': 'Test Title'
+        }])
         self.NereidWebsite.create([{
             'name': 'localhost',
-            'shop': self.shop,
+            'channel': self.channel,
             'company': self.company.id,
             'application_user': USER,
             'default_locale': self.locale_en_us.id,
             'guest_user': self.guest_user,
             'countries': [('add', self.available_countries)],
             'currencies': [('add', [self.usd.id])],
+            'homepage_menu': self.default_menuitem.id,
         }])
 
         # Create an article category
@@ -477,14 +523,12 @@ class BaseTestCase(NereidTestCase):
         }])
 
         # Product categories
-        self.category, = self._create_product_category(
-            'categ1', [{'uri': 'category1   '}]
-        )
-        self.category2, = self._create_product_category(
-            'categ2', [{'uri': 'category2'}]
-        )
-        self.category3, = self._create_product_category(
-            'categ3', [{'uri': 'category3'}]
+        self.category, = self._create_product_category('categ1', [{}])
+        self.category2, = self._create_product_category('categ2', [{}])
+        self.category3, = self._create_product_category('categ3', [{}])
+
+        self.Account.write(
+            self.Account.search([]), {'party_required': True}
         )
 
     def login(self, client, username, password, assert_=True):
