@@ -2,19 +2,20 @@
 
     Test Templates
 
-    :copyright: (c) 2014 by Openlabs Technologies & Consulting (P) LTD
+    :copyright: (c) 2014-2015 by Openlabs Technologies & Consulting (P) LTD
     :license: GPLv3, see LICENSE for more details
 '''
-import random
 import unittest
-from trytond.tests.test_tryton import USER, DB_NAME, CONTEXT
+import datetime
+import trytond
+from trytond.tests.test_tryton import USER, DB_NAME, CONTEXT, POOL
 from trytond.transaction import Transaction
 from test_base import BaseTestCase
-from trytond.config import CONFIG
+from trytond.config import config
 from decimal import Decimal
 from nereid import request
 
-CONFIG['smtp_from'] = 'from@xyz.com'
+config.set('email', 'from', 'from@xyz.com')
 
 
 class TestTemplates(BaseTestCase):
@@ -22,96 +23,13 @@ class TestTemplates(BaseTestCase):
     Test case for templates in nereid-webshop.
     """
 
-    def create_test_products(self):
-        # Create product templates with products
-        self._create_product_template(
-            'product 1',
-            [{
-                'category': self.category.id,
-                'type': 'goods',
-                'salable': True,
-                'list_price': Decimal('10'),
-                'cost_price': Decimal('5'),
-                'account_expense': self._get_account_by_kind('expense').id,
-                'account_revenue': self._get_account_by_kind('revenue').id,
-            }],
-            uri='product-1',
-        )
-        self._create_product_template(
-            'product 2',
-            [{
-                'category': self.category2.id,
-                'type': 'goods',
-                'salable': True,
-                'list_price': Decimal('20'),
-                'cost_price': Decimal('5'),
-                'account_expense': self._get_account_by_kind('expense').id,
-                'account_revenue': self._get_account_by_kind('revenue').id,
-            }],
-            uri='product-2',
-        )
-        self._create_product_template(
-            'product 3',
-            [{
-                'category': self.category3.id,
-                'type': 'goods',
-                'list_price': Decimal('30'),
-                'cost_price': Decimal('5'),
-                'account_expense': self._get_account_by_kind('expense').id,
-                'account_revenue': self._get_account_by_kind('revenue').id,
-            }],
-            uri='product-3',
-        )
-        self._create_product_template(
-            'product 4',
-            [{
-                'category': self.category3.id,
-                'type': 'goods',
-                'list_price': Decimal('30'),
-                'cost_price': Decimal('5'),
-                'account_expense': self._get_account_by_kind('expense').id,
-                'account_revenue': self._get_account_by_kind('revenue').id,
-            }],
-            uri='product-4',
-            displayed_on_eshop=False
-        )
-
-    def _create_product_template(
-        self, name, vlist, uri, uom=u'Unit', displayed_on_eshop=True
-    ):
+    def setUp(self):
         """
-        Create a product template with products and return its ID
-
-        :param name: Name of the product
-        :param vlist: List of dictionaries of values to create
-        :param uri: uri of product template
-        :param uom: Note it is the name of UOM (not symbol or code)
-        :param displayed_on_eshop: Boolean field to display product
-                                   on shop or not
+        setUp method
         """
-        _code_list = []
-        code = random.choice('ABCDEFGHIJK')
-        while code in _code_list:
-            code = random.choice('ABCDEFGHIJK')
-        else:
-            _code_list.append(code)
+        trytond.tests.test_tryton.install_module('nereid_catalog_variants')
 
-        for values in vlist:
-            values['name'] = name
-            values['default_uom'], = self.Uom.search(
-                [('name', '=', uom)], limit=1
-            )
-            values['sale_uom'], = self.Uom.search(
-                [('name', '=', uom)], limit=1
-            )
-            values['products'] = [
-                ('create', [{
-                    'uri': uri,
-                    'displayed_on_eshop': displayed_on_eshop,
-                    'code': code,
-                }])
-            ]
-        return self.ProductTemplate.create(vlist)
+        super(TestTemplates, self).setUp()
 
     def cart(self, to_login):
         """
@@ -124,9 +42,10 @@ class TestTemplates(BaseTestCase):
             self.setup_defaults()
             app = self.get_app()
             self.create_test_products()
-            product1, = self.ProductTemplate.search([
+            template1, = self.ProductTemplate.search([
                 ('name', '=', 'product 1')
             ])
+            product1 = template1.products[0]
 
             with app.test_client() as c:
                 if to_login:
@@ -729,7 +648,7 @@ class TestTemplates(BaseTestCase):
                         'expiry_year': '2018',
                         'expiry_month': '01',
                         'cvv': '911',
-                        'add_card_to_profiles': 'y',
+                        'add_card_to_profiles': True,
                     }
                 )
                 self.assertEqual(rv.status_code, 302)
@@ -737,6 +656,8 @@ class TestTemplates(BaseTestCase):
                 self.assertTrue('access_code' in rv.location)
 
                 sale, = self.Sale.search([('state', '=', 'confirmed')])
+                self.Sale.proceed([sale])
+                self.Sale.process_all_pending_payments()
                 payment_transaction, = sale.gateway_transactions
                 self.assertEqual(payment_transaction.amount, sale.total_amount)
 
@@ -846,6 +767,8 @@ class TestTemplates(BaseTestCase):
                 self.assertTrue('access_code' in rv.location)
 
                 sale, = self.Sale.search([('state', '=', 'confirmed')])
+                self.Sale.proceed([sale])
+                self.Sale.process_all_pending_payments()
                 payment_transaction, = sale.gateway_transactions
                 self.assertEqual(payment_transaction.amount, sale.total_amount)
 
@@ -1035,6 +958,10 @@ class TestTemplates(BaseTestCase):
             with app.test_client() as c:
                 self.create_test_products()
 
+                template1, = self.ProductTemplate.search([
+                    ('name', '=', 'product 1')
+                ])
+
                 rv = c.get('/products')
                 self.assertIn('product 1', rv.data)
                 self.assertIn('product 2', rv.data)
@@ -1071,3 +998,107 @@ class TestTemplates(BaseTestCase):
                 self.assertIn('product-2', rv.data)
                 self.assertIn('product 3', rv.data)
                 self.assertIn('product-3', rv.data)
+
+    def test_0090_product_inventory(self):
+        """
+        Tests the product template for cases of 'In Stock', 'Out Of Stock' and
+        'X <uom>s available'.
+        """
+        StockMove = POOL.get('stock.move')
+
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
+            self.setup_defaults()
+            del self.templates['product.jinja']
+
+            app = self.get_app()
+
+            self.create_test_products()
+            template1, = self.ProductTemplate.search([
+                ('name', '=', 'product 1')
+            ])
+            product1 = template1.products[0]
+
+            with app.test_request_context('/'):
+                # Check serialize method
+                res = product1.serialize(purpose='variant_selection')
+                self.assertIn('inventory_status', res)
+
+            with app.test_client() as c:
+                rv = c.get('/product/product-1')
+
+                # No inventory made yet, and product is goods type
+                self.assertIn('In stock', rv.data)
+
+            # Let's create inventory
+            website, = self.NereidWebsite.search([])
+            supplier, = self.Location.search([('code', '=', 'SUP')])
+            stock1, = StockMove.create([{
+                'product': product1.id,
+                'uom': template1.sale_uom.id,
+                'quantity': 10,
+                'from_location': supplier,
+                'to_location': website.stock_location.id,
+                'company': website.company.id,
+                'unit_price': Decimal('1'),
+                'currency': website.currencies[0].id,
+                'planned_date': datetime.date.today(),
+                'effective_date': datetime.date.today(),
+                'state': 'draft',
+            }])
+            StockMove.write([stock1], {
+                'state': 'done'
+            })
+
+            product1.display_available_quantity = True
+            product1.start_displaying_available_quantity = 10
+            product1.min_warehouse_quantity = 5
+            product1.save()
+
+            # min_warehouse_quantity < quantity <= start_displaying
+            with app.test_client() as c:
+                rv = c.get('/product/product-1')
+
+                # X <uom> available
+                self.assertIn(
+                    str(product1.get_availability().get('quantity')) +
+                    ' ' + product1.default_uom.name,
+                    rv.data
+                )
+
+            product1.start_displaying_available_quantity = 3
+            product1.save()
+
+            # min_warehouse_quantity < quantity
+            with app.test_client() as c:
+                rv = c.get('/product/product-1')
+
+                # In Stock
+                self.assertIn('In stock', rv.data)
+
+            product1.min_warehouse_quantity = 11
+            product1.save()
+
+            # min_warehouse_quantity > quantity
+            with app.test_client() as c:
+                rv = c.get('/product/product-1')
+
+                # Out Of Stock
+                self.assertIn('Out of stock', rv.data)
+
+            product1.min_warehouse_quantity = 0
+            product1.save()
+
+            with app.test_client() as c:
+                rv = c.get('/product/product-1')
+
+                # Only in stock and out of stock cases
+                self.assertIn('In stock', rv.data)
+
+            product1.min_warehouse_quantity = -1
+            product1.save()
+
+            with app.test_client() as c:
+                rv = c.get('/product/product-1')
+
+                # Always in stock
+                self.assertIn('In stock', rv.data)
