@@ -15,7 +15,10 @@ from nereid import current_app, route, render_template, request, jsonify
 from trytond.pyson import Eval, Not
 
 __metaclass__ = PoolMeta
-__all__ = ['WebShop', 'BannerCategory', 'Banner', 'Article', 'Website']
+__all__ = [
+    'WebShop', 'BannerCategory', 'Banner', 'Article',
+    'Website', 'ArticleCategory', 'MenuItem'
+]
 
 #: Get the static folder. The static folder also
 #: goes into the site packages
@@ -75,6 +78,20 @@ class Article:
         return True
 
 
+class ArticleCategory:
+    "CMS Article Category"
+    __name__ = 'nereid.cms.article.category'
+
+    @staticmethod
+    def check_xml_record(records, values):
+        """The webshop module creates a bunch of commonly used article category on
+        webshops. Since tryton does not allow records created via XML to be
+        edited, this method explicitly allows users to modify the article
+        category created by the module.
+        """
+        return True
+
+
 class Website:
     "Nereid Website"
     __name__ = 'nereid.website'
@@ -94,6 +111,18 @@ class Website:
         depends=['show_site_message']
     )
 
+    copyright_year_range = fields.Char('Copyright Year Range')
+
+    cms_root_footer = fields.Many2One(
+        'nereid.cms.menuitem', "CMS root Footer", ondelete='RESTRICT',
+        select=True,
+    )
+
+    homepage_menu = fields.Many2One(
+        'nereid.cms.menuitem', "Homepage Menu", ondelete='RESTRICT',
+        select=True,
+    )
+
     @classmethod
     @route('/sitemap', methods=["GET"])
     def render_sitemap(cls):
@@ -152,3 +181,31 @@ class Website:
             * Add article search.
         """
         return super(Website, cls).quick_search()
+
+    @staticmethod
+    def default_cms_root_footer():
+        """
+        Get default record from xml
+        """
+        ModelData = Pool().get('ir.model.data')
+
+        menu_item_id = ModelData.get_id("nereid_webshop", "cms_root_footer")
+        return menu_item_id
+
+
+class MenuItem:
+    __name__ = 'nereid.cms.menuitem'
+
+    @staticmethod
+    def check_xml_record(records, values):
+        return True
+
+    @classmethod
+    def allowed_models(cls):
+        res = super(MenuItem, cls).allowed_models()
+
+        if ('product.tree_node', 'Tree Node') not in res:
+            res.append(('product.tree_node', 'Tree Node'))
+        if ('product.product', 'Product') not in res:
+            res.append(('product.product', 'Product'))
+        return res
